@@ -82,7 +82,7 @@ impl CodeScanning {
             query
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -138,7 +138,7 @@ impl CodeScanning {
             query
         );
 
-        self.client.get_all_pages(&url).await
+        self.client.get_all_pages(&url, None).await
     }
 
     /**
@@ -172,7 +172,7 @@ impl CodeScanning {
             crate::progenitor_support::encode_path(&alert_number.to_string()),
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -264,7 +264,7 @@ impl CodeScanning {
             query
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -304,7 +304,7 @@ impl CodeScanning {
             query
         );
 
-        self.client.get_all_pages(&url).await
+        self.client.get_all_pages(&url, None).await
     }
 
     /**
@@ -386,7 +386,7 @@ impl CodeScanning {
             query
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -451,7 +451,7 @@ impl CodeScanning {
             query
         );
 
-        self.client.get_all_pages(&url).await
+        self.client.get_all_pages(&url, None).await
     }
 
     /**
@@ -502,7 +502,7 @@ impl CodeScanning {
             crate::progenitor_support::encode_path(&analysis_id.to_string()),
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -590,7 +590,7 @@ impl CodeScanning {
         repo: &str,
         analysis_id: i64,
         confirm_delete: &str,
-    ) -> Result<crate::types::CodeScanningAnalysisDeletion> {
+    ) -> Result<crate::types::AnalysisDeletion> {
         let mut query = String::new();
         let mut query_args: Vec<String> = Default::default();
         if !confirm_delete.is_empty() {
@@ -691,6 +691,6 @@ impl CodeScanning {
             crate::progenitor_support::encode_path(&sarif_id.to_string()),
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 }
