@@ -1,7 +1,3 @@
-use std::{fmt, str::FromStr};
-
-use serde::de::{self, Visitor};
-
 //const X_GITHUB_REQUEST_ID: &str = "x-github-request-id";
 //const X_RATELIMIT_LIMIT: &str = "x-ratelimit-limit";
 const X_RATELIMIT_REMAINING: &str = "x-ratelimit-remaining";
@@ -96,6 +92,10 @@ impl From<MediaType> for mime::Mime {
     }
 }
 
+use std::{fmt, str::FromStr};
+
+use serde::de::{self, Visitor};
+
 // TODO: we should add a function for deserializing a null vector.
 pub mod deserialize_null_string {
     use serde::{self, Deserialize, Deserializer};
@@ -191,6 +191,20 @@ impl<'de> Visitor<'de> for I32Visitor {
         formatter.write_str("an integer between -2^31 and 2^31")
     }
 
+    fn visit_i8<E>(self, value: i8) -> Result<Self::Value, E>
+    where
+        E: de::Error,
+    {
+        Ok(value as i32)
+    }
+
+    fn visit_i16<E>(self, value: i16) -> Result<Self::Value, E>
+    where
+        E: de::Error,
+    {
+        Ok(value as i32)
+    }
+
     fn visit_i32<E>(self, value: i32) -> Result<Self::Value, E>
     where
         E: de::Error,
@@ -209,6 +223,13 @@ impl<'de> Visitor<'de> for I32Visitor {
             Err(E::custom(format!("i32 out of range: {}", value)))
         }
     }
+
+    fn visit_u64<E>(self, value: u64) -> Result<Self::Value, E>
+    where
+        E: de::Error,
+    {
+        Ok(value as i32)
+    }
 }
 
 pub mod deserialize_null_i32 {
@@ -242,12 +263,40 @@ impl<'de> Visitor<'de> for I64Visitor {
         formatter.write_str("an integer")
     }
 
+    fn visit_i8<E>(self, value: i8) -> Result<Self::Value, E>
+    where
+        E: de::Error,
+    {
+        Ok(value as i64)
+    }
+
+    fn visit_i16<E>(self, value: i16) -> Result<Self::Value, E>
+    where
+        E: de::Error,
+    {
+        Ok(value as i64)
+    }
+
+    fn visit_i32<E>(self, value: i32) -> Result<Self::Value, E>
+    where
+        E: de::Error,
+    {
+        Ok(value as i64)
+    }
+
     fn visit_i64<E>(self, value: i64) -> Result<Self::Value, E>
     where
         E: de::Error,
     {
         Ok(value)
     }
+
+    fn visit_u64<E>(self, value: u64) -> Result<Self::Value, E>
+    where
+        E: de::Error,
+    {
+        Ok(value as i64)
+    }
 }
 
 pub mod deserialize_null_i64 {
@@ -281,6 +330,46 @@ impl<'de> Visitor<'de> for F32Visitor {
         formatter.write_str("a float between -2^31 and 2^31")
     }
 
+    fn visit_i8<E>(self, value: i8) -> Result<Self::Value, E>
+    where
+        E: de::Error,
+    {
+        Ok(value as f32)
+    }
+
+    fn visit_i16<E>(self, value: i16) -> Result<Self::Value, E>
+    where
+        E: de::Error,
+    {
+        Ok(value as f32)
+    }
+
+    fn visit_i32<E>(self, value: i32) -> Result<Self::Value, E>
+    where
+        E: de::Error,
+    {
+        Ok(value as f32)
+    }
+
+    fn visit_i64<E>(self, value: i64) -> Result<Self::Value, E>
+    where
+        E: de::Error,
+    {
+        use std::i32;
+        if value >= i64::from(i32::MIN) && value <= i64::from(i32::MAX) {
+            Ok(value as f32)
+        } else {
+            Err(E::custom(format!("f32 out of range: {}", value)))
+        }
+    }
+
+    fn visit_u64<E>(self, value: u64) -> Result<Self::Value, E>
+    where
+        E: de::Error,
+    {
+        Ok(value as f32)
+    }
+
     fn visit_f32<E>(self, value: f32) -> Result<Self::Value, E>
     where
         E: de::Error,
@@ -332,6 +421,48 @@ impl<'de> Visitor<'de> for F64Visitor {
         formatter.write_str("a float")
     }
 
+    fn visit_i8<E>(self, value: i8) -> Result<Self::Value, E>
+    where
+        E: de::Error,
+    {
+        Ok(value as f64)
+    }
+
+    fn visit_i16<E>(self, value: i16) -> Result<Self::Value, E>
+    where
+        E: de::Error,
+    {
+        Ok(value as f64)
+    }
+
+    fn visit_i32<E>(self, value: i32) -> Result<Self::Value, E>
+    where
+        E: de::Error,
+    {
+        Ok(value as f64)
+    }
+
+    fn visit_i64<E>(self, value: i64) -> Result<Self::Value, E>
+    where
+        E: de::Error,
+    {
+        Ok(value as f64)
+    }
+
+    fn visit_u64<E>(self, value: u64) -> Result<Self::Value, E>
+    where
+        E: de::Error,
+    {
+        Ok(value as f64)
+    }
+
+    fn visit_f32<E>(self, value: f32) -> Result<Self::Value, E>
+    where
+        E: de::Error,
+    {
+        Ok(value as f64)
+    }
+
     fn visit_f64<E>(self, value: f64) -> Result<Self::Value, E>
     where
         E: de::Error,
